@@ -25,7 +25,7 @@
 #include "SmiImpl.h"
 #include "smbios/ISmbios.h"
 #include "smbios/IToken.h"
-#include "../token/TokenLowLevel.h"
+#include "TokenLowLevel.h"
 
 using namespace std;
 
@@ -356,7 +356,7 @@ out:
     {
         u32 authKey = 0;
 
-        DCERR("getAuthenticationKey()" << endl);
+        DCERR("getAuthenticationKey(" << password << ")" << endl);
 
         // try admin password first, then user password
         u16 toCheck[2] = { class_admin_password, class_user_password };
@@ -393,9 +393,10 @@ out:
 
             DCERR("    args are  : 0x" << args[0] << " 0x" << args[1] << " 0x" << args[2] << " 0x" << args[3] << endl);
 
-            // if SMI above succeeded, this should to, no exception handling
+            // if SMI above succeeded, this should too, no exception handling
             doSimpleCallingInterfaceSmi(toCheck[i], 1, args, res);
 
+            DCERR("    res was  : 0x" << res[0] << " 0x" << res[1] << " 0x" << res[2] << " 0x" << res[3] << endl);
             if( res[0] == 0 )
                 authKey = res[1];
             else
@@ -510,7 +511,10 @@ out:
             try
             {
                 // 0 == class code for writing to setting/battery/ac/systemstatus
+                DCERR("Try #" << i << " for writeSetting()" << endl);
+                DCERR("    args are  : 0x" << args[0] << " 0x" << args[1] << " 0x" << args[2] << " 0x" << args[3] << endl);
                 doSimpleCallingInterfaceSmi(1, select, args, res);
+                DCERR("    res was  : 0x" << res[0] << " 0x" << res[1] << " 0x" << res[2] << " 0x" << res[3] << endl);
                 break;
             }
             catch(const SmiExecutedWithError &)
@@ -519,6 +523,7 @@ out:
                 if(i==1)
                     throw;
 
+                DCERR("Executed with error, try password..." << endl);
                 args[2] = getAuthenticationKey(password);
             }
         }
