@@ -32,11 +32,12 @@ namespace smbios
     {}
 
     IProtectedToken::IProtectedToken()
-            : IToken()
     {}
 
     ICmosToken::ICmosToken()
-            : IToken()
+    {}
+
+    ISmiToken::ISmiToken()
     {}
 
     // no dynamically allocated memory, yay!
